@@ -37,6 +37,9 @@
 #include "CandidateCarbon.h"
 
 
+//#define DEBUG_CANDIDATES 1
+
+
 extern uim_context gUC;
 
 
@@ -54,21 +57,32 @@ LayoutCandidate(MUIMSessionHandle inHandle)
 {
   TSMStat tsmStat;
   OSErr err = noErr;
-  SInt16 qdX = 0, qdY = 0;
 
   tsmStat.fRefCon = 0;
   tsmStat.fTextOffset = 0;
   tsmStat.fSLRec.fScript = smJapanese;
   tsmStat.fSLRec.fLanguage = langJapanese;
   tsmStat.fLeadingEdge = FALSE;
+  tsmStat.fReplyPoint.v = 0;
+  tsmStat.fReplyPoint.h = 0;
+  tsmStat.fReplyFont = 0;
+  tsmStat.fReplyPointSize = 0;
+  tsmStat.fReplyLineHeight = 0;
 
   err = MUIMGetTSMStatus(inHandle, &tsmStat);
-  if (err == noErr) {
-    qdX = tsmStat.fReplyPoint.h;
-    qdY = tsmStat.fReplyPoint.v;
-  }
 
-  ShowCandidateWindow(inHandle, qdX, qdY);
+#ifdef DEBUG_CANDIDATES
+  DEBUG_PRINT("LayoutCandidate() tsmStat.fReplyPoint: v=%d h=%d\n",
+              tsmStat.fReplyPoint.v, tsmStat.fReplyPoint.h);
+  DEBUG_PRINT("LayoutCandidate() tsmStat.fReplyFont=%ld\n",
+              tsmStat.fReplyFont);
+  //DEBUG_PRINT("LayoutCandidate() tsmStat.fReplyPointSize=%ld\n",
+  //            tsmStat.fReplyPointSize);
+  DEBUG_PRINT("LayoutCandidate() tsmStat.fReplyLineHeight=%d\n",
+              tsmStat.fReplyLineHeight);
+#endif
+
+  ShowCandidateWindow(inHandle, &tsmStat);
 }
 
 OSStatus
@@ -80,7 +94,7 @@ InitCandidateWindow(MUIMSessionHandle inHandle)
   CFURLRef baseURL2 = NULL;
   CFURLRef bundleURL = NULL;
   CFURLRef bundleURL2 = NULL;
-  OSStatus (*funcPtr)(void *);
+  OSStatus (*initPtr)(void *);
 
   //char buf[BUFSIZ];
   //CFIndex len;
@@ -130,11 +144,11 @@ InitCandidateWindow(MUIMSessionHandle inHandle)
   CFRelease(bundleURL);
 
   // call function to initialize bundle
-  funcPtr = CFBundleGetFunctionPointerForName((*inHandle)->fBundleRef,
+  initPtr = CFBundleGetFunctionPointerForName((*inHandle)->fBundleRef,
                                               CFSTR("initializeBundle"));
-  require(funcPtr, CantFindFunction);
+  require(initPtr, CantFindFunction);
 
-  res = (*funcPtr)(HandleBundleCommand);
+  res = (*initPtr)(HandleBundleCommand);
   require_noerr(res, CantInitializeBundle);
                 
  CantCreateBundleURL:
@@ -150,13 +164,12 @@ InitCandidateWindow(MUIMSessionHandle inHandle)
 
 OSStatus
 ShowCandidateWindow(MUIMSessionHandle inHandle,
-                    SInt16 inQDX, SInt16 inQDY)
+                    TSMStat *inTSMStat)
 {
   OSStatus res = noErr;
   UInt32 i;
-  OSStatus (*showPtr)(SInt16, SInt16);
+  OSStatus (*showPtr)(SInt16, SInt16, SInt16);
   OSStatus (*pagePtr)(int, int);
-  //char idx[16];
 
   if (!(*inHandle)->fBundleRef)
     return noErr;
@@ -245,7 +258,9 @@ ShowCandidateWindow(MUIMSessionHandle inHandle,
   showPtr = CFBundleGetFunctionPointerForName((*inHandle)->fBundleRef,
                                               CFSTR("orderWindowFront"));
   if (showPtr)
-    res = (*showPtr)(inQDX, inQDY);
+    res = (*showPtr)(inTSMStat->fReplyPoint.h,
+                     inTSMStat->fReplyPoint.v,
+                     inTSMStat->fReplyLineHeight);
 
   (*inHandle)->fWindowOpened = true;
 
@@ -380,7 +395,9 @@ static OSStatus
 HandleBundleCommand(int commandID) {
   OSStatus res = noErr;
 
+#ifdef DEBUG_CANDIDATES
   DEBUG_PRINT("HandleBundleCommand() commandID=%d\n", commandID);
+#endif
 
 #if 0
   if (commandID == kEventCandClicked) {
