@@ -60,6 +60,11 @@ static CandidateController *sharedController;
   //printf("origsize: width=%f height=%f\n",
   //       origSize.width, origSize.height);
 
+  [window setFrame:NSMakeRect([window frame].origin.x,
+                              [window frame].origin.y,
+                              origSize.width, 37)
+          display:NO];
+
   return self;
 }
 
@@ -78,6 +83,8 @@ static CandidateController *sharedController;
 {
   lineHeight = height;
 
+  //printf("CandidateController::showWindow:\n");
+
   [window setAutodisplay:NO];
 
   //[table setHidden:YES];
@@ -112,13 +119,16 @@ static CandidateController *sharedController;
 {
   NSPoint origin = [window frame].origin;
 
+  if ([window isVisible] == NO)
+    return;
+
   //printf("CandidateController::hideWindow\n");
 
   [window orderOut:nil];
 
   [[table tableColumnWithIdentifier:@"candidate"] setWidth:36];
   [window setFrame:NSMakeRect(origin.x, origin.y,
-                              origSize.width, origSize.height)
+                              origSize.width, 37)
           display:NO];
 }
 
@@ -144,6 +154,7 @@ static CandidateController *sharedController;
  */
 - (int)numberOfRowsInTableView:(NSTableView *)aTableView
 {
+#if 0
   int i = 0;
 
   if ([candArray count] == 0)
@@ -160,8 +171,9 @@ static CandidateController *sharedController;
   }
 
   return i;
-
-  //return [candArray count];
+#else
+  return [candArray count];
+#endif
 }
 
 /**
@@ -292,10 +304,8 @@ static CandidateController *sharedController;
   NSTableColumn *col = [table tableColumnWithIdentifier:@"candidate"];
   NSSize mainSize = [[NSScreen mainScreen] frame].size;
   NSRect rect = [window frame];
-  int x;
-  int y;
   float columnWidth = 0.0;
-  int i;
+  int x, y, i;
 
   for (i = 0; i < [candArray count]; i++) {
     NSMutableAttributedString *text =
@@ -325,8 +335,23 @@ static CandidateController *sharedController;
     i++;
   }
 
-  [window setContentSize:NSMakeSize([table frame].size.width + 2,
-                                    17 * i + 20)];
+
+  if ([[window contentView] frame].size.height < 17 * i + 20) {
+    [window setContentSize:NSMakeSize([table frame].size.width + 2,
+                                      17 * i + 20)];
+  }
+  else if ([[window contentView] frame].size.width <
+          [table frame].size.width + 2) {
+    [window setContentSize:NSMakeSize([table frame].size.width + 2,
+                                      [[window contentView] frame].size.height)];
+  }
+
+  //[window setContentSize:NSMakeSize([table frame].size.width + 2,
+  //                                  17 * i + 20)];
+
+  [table setFrameSize:NSMakeSize([table frame].size.width,
+                                 17 * i)];
+
   rect = [window frame];
 
   x = replyX;
