@@ -54,6 +54,8 @@
 //#define DEBUG_MENU  1
 //#define DEBUG_CANDIDATES  1
 //#define DEBUG_SESSION  1
+//#define DEBUG_UIM  1
+//#define DEBUG_PRIME  1
 
 
 const short kMENU_Pencil = kBaseResourceID + 1;
@@ -256,8 +258,15 @@ MUIMInitialize(ComponentInstance inComponentInstance,
     }
   }
 
-  // for Uim debug
-  //setenv("LIBUIM_VERBOSE", "5", 1);
+#ifdef DEBUG_UIM
+  // Uim debug
+  setenv("LIBUIM_VERBOSE", "3", 1);
+#endif
+
+#ifdef DEBUG_PRIME
+  // PRIME debug
+  setenv("PRIME_DEBUG", "1", 1);
+#endif
 
   uim_init();
 
