@@ -87,6 +87,9 @@ typedef struct _TSMStat {
   ScriptLanguageRecord fSLRec;
   Boolean fLeadingEdge;
   Point fReplyPoint;
+  long fReplyFont;
+  Fixed fReplyPointSize;
+  short fReplyLineHeight;
 
 } TSMStat;
 
