@@ -146,7 +146,7 @@ MUIMComponentDispatch(ComponentParameters * inParams, Handle inSessionHandle)
     break;
 
   case kCMHidePaletteWindows:
-    DEBUG_PRINT("MUIMComponentDispatch() kCMHidePaletteWindows\n");
+    //DEBUG_PRINT("MUIMComponentDispatch() kCMHidePaletteWindows\n");
     break;
 
   /*
@@ -194,7 +194,7 @@ MUIMOpenComponent(ComponentInstance inComponentInstance)
   ComponentResult result = noErr;
   Handle sessionHandle = nil;
 
-  DEBUG_PRINT("MUIMOpenComponent() count=%ld + 1\n", gInstanceRefCount);
+  //DEBUG_PRINT("MUIMOpenComponent() count=%ld + 1\n", gInstanceRefCount);
 
   if (gInstanceRefCount == 0)
     result = MUIMInitialize(inComponentInstance, &gTextServiceMenu);
@@ -229,7 +229,7 @@ MUIMCloseComponent(Handle inSessionHandle, ComponentInstance inComponentInstance
 {
   ComponentResult result = noErr;
 
-  DEBUG_PRINT("MUIMCloseComponent() count=%d - 1\n", gInstanceRefCount);
+  //DEBUG_PRINT("MUIMCloseComponent() count=%d - 1\n", gInstanceRefCount);
 
   if (inComponentInstance == nil)
     result = paramErr;
