@@ -138,18 +138,7 @@
 
 - (void)didUnselect
 {
-  CFNotificationCenterRef center;
-
   [self prefSync];
-
-  // Write out all the changes
-  CFPreferencesAppSynchronize(appID);
-
-  // Post a notification that the preferences have changed
-  center = CFNotificationCenterGetDistributedCenter();
-  CFNotificationCenterPostNotification(center,
-                                       CFSTR("Preferences Changed"),
-                                       appID, NULL, TRUE);
 }
 
 /**
@@ -158,9 +147,6 @@
 - (IBAction)imChange:(id)sender
 {
   [self prefSync];
-  
-  // Force a synchronization so our preference is "live"
-  CFPreferencesAppSynchronize(appID);
 }
 
 - (IBAction)appletChange:(id)sender
@@ -184,17 +170,57 @@
 
 - (void)prefSync
 {
-  int i = [[imButton objectValue] intValue];
+  CFNotificationCenterRef center;
+  CFStringRef keys[1];
+  CFStringRef values[1];
+  CFDictionaryRef dict;
+  int i;
+
+  //keys = (CFStringRef *) NewPtrClear(sizeof(CFStringRef));
+  //values = (CFStringRef *) NewPtrClear(sizeof(CFStringRef));
+
+  keys[0] = CFStringCreateWithCString(NULL, "IM",
+                                      kCFStringEncodingMacRoman);
+
+  values[0] = CFStringCreateWithCString(NULL, kDefaultIM,
+                                        kCFStringEncodingMacRoman);
+
+  i = [[imButton objectValue] intValue];
 
   CFPreferencesSetAppValue(CFSTR("InputMethod"),
                            CFSTR(kDefaultIM), appID);
 
   if ([[imButton objectValue] intValue] < numModules) {
-    if (imModules && imModules[i])
+    if (imModules && imModules[i]) {
       CFPreferencesSetAppValue(CFSTR("InputMethod"),
                                (CFStringRef) [NSString stringWithCString:imModules[i]->name],
                                appID);
+      CFRelease(values[0]);
+      values[0] = CFStringCreateWithCString(NULL, imModules[i]->name,
+                                            kCFStringEncodingMacRoman);
+    }
   }
+
+  // Write out all the changes
+  CFPreferencesAppSynchronize(appID);
+
+  dict = CFDictionaryCreate(kCFAllocatorDefault, 
+                            (const void **) keys, 
+                            (const void **) values,
+                            1, 
+                            //&kCFTypeDictionaryKeyCallBacks,
+                            //&kCFTypeDictionaryValueCallBacks
+                            NULL, NULL);
+
+  // Post a notification that the preferences have changed
+  center = CFNotificationCenterGetDistributedCenter();
+  CFNotificationCenterPostNotification(center,
+                                       CFSTR("Preferences Changed"),
+                                       appID, dict, TRUE);
+
+  CFRelease(keys[0]);
+  CFRelease(values[0]);
+  CFRelease(dict);
 }
 
 - (void)loadExtra
